@@ -102,6 +102,13 @@ class Costumers:
     def __init__(self, asaas: Asaas):
         self.asaas = asaas
         self.endpoint = 'customers'
+        
+    
+    def response_data_to_customer(
+        self,
+        data: dict
+    ):
+        return customer.Customer(**data)
 
     def retrieve(
         self,
@@ -111,7 +118,7 @@ class Costumers:
 
         response = self.asaas.get(f'{self.endpoint}/{customer_id}')
 
-        return customer.Customer(**response.json())
+        return self.response_data_to_customer(response.json())
 
     def create(
         self,
@@ -161,7 +168,7 @@ class Costumers:
 
         response = self.asaas.post(f'{self.endpoint}', data)
 
-        return customer.Customer(**response.json())
+        return self.response_data_to_customer(response.json())
 
     def list(
         self,
@@ -189,7 +196,7 @@ class Costumers:
 
         response = self.asaas.get(self.endpoint, params)
 
-        return [customer.Customer(**customer_dict) for customer_dict in response.json()['data']]
+        return [self.response_data_to_customer(customer_dict) for customer_dict in response.json()['data']]
 
     def update(
         self,
@@ -243,7 +250,7 @@ class Costumers:
             data
         )
 
-        return customer.Customer(**response.json())
+        return self.response_data_to_customer(response.json())
 
     def delete(
         self,
@@ -261,16 +268,10 @@ class Costumers:
 
         response = self.asaas.post(f'{self.endpoint}/{customer_id}/restore')
 
-        return customer.Customer(**response.json())
+        return self.response_data_to_customer(response.json())
 
 
-class Payments:
-    """Class to manage payments in Asaas API"""
-
-    def __init__(self, asaas: Asaas):
-        self.asaas = asaas
-        self.endpoint = 'payments'
-
+class ResponseDataToPayment:
     def response_data_to_payment(
         self,
         data: dict
@@ -302,6 +303,14 @@ class Payments:
 
         return payments.Payment(**data)
 
+
+class Payments(ResponseDataToPayment):
+    """Class to manage payments in Asaas API"""
+
+    def __init__(self, asaas: Asaas):
+        self.asaas = asaas
+        self.endpoint = 'payments'
+
     def retrieve(
         self,
         payment_id: str
@@ -524,7 +533,7 @@ class Payments:
         return self.response_data_to_payment(response.json())
 
 
-class Subscriptions:
+class Subscriptions(ResponseDataToPayment):
     """Class to manage subscriptions in Asaas API"""
 
     def __init__(self, asaas: Asaas):
@@ -537,14 +546,6 @@ class Subscriptions:
     ):
         """Convert response data to Subscription object"""
 
-        data['cicle'] = subscriptions.Cycle(
-            **data['cicle']
-        )
-
-        data['status'] = subscriptions.Status(
-            data['status']
-        )
-
         data['discount'] = payments.Discount(
             **data['discount']
         ) if data.get('discount') else None
@@ -554,7 +555,8 @@ class Subscriptions:
         ) if data.get('interest') else None
 
         data['fine'] = payments.Fine(
-            **data['fine']) if data.get('fine') else None
+            **data['fine']
+        ) if data.get('fine') else None
 
         data['split'] = [
             payments.Split(**split) for split in data['split']
@@ -594,7 +596,7 @@ class Subscriptions:
         discount = discount.to_dict() if discount else None
         interest = interest.to_dict() if interest else None
         fine = fine.to_dict() if fine else None
-        split = split.to_dict() if split else None
+        split = [s.to_dict() for s in split] if split else None
         callback = callback.to_dict() if callback else None
 
         data = remove_none_and_empty_values(
@@ -679,7 +681,7 @@ class Subscriptions:
         discount = discount.to_dict() if discount else None
         interest = interest.to_dict() if interest else None
         fine = fine.to_dict() if fine else None
-        split = split.to_dict() if split else None
+        split = [s.to_dict() for s in split] if split else None
         callback = callback.to_dict() if callback else None
 
         data = remove_none_and_empty_values(
@@ -732,4 +734,4 @@ class Subscriptions:
         response = self.asaas.get(
             f'{self.endpoint}/{subscription_id}/payments', params)
 
-        return [payments.Payment(**payment) for payment in response.json()['data']]
+        return self.response_data_to_payment(response.json()['data'])
